# jsutils api
js工具类

[时间示例演示：https://zhtt.gitee.io/angular-demo/great-ngform6/#/jsutils/time-test](https://zhtt.gitee.io/angular-demo/great-ngform6/#/jsutils/time-test)

[数组示例演示：https://zhtt.gitee.io/angular-demo/great-ngform6/#/jsutils/array-test](https://zhtt.gitee.io/angular-demo/great-ngform6/#/jsutils/array-test)
## 安装
```
npm i great-jsutils --save
```
## License
请查看 [MIT license](./LICENSE).

## 一、数组
```js
import { ArrayUtils } from 'great-jsutils';
```
### 添加元素
**ArrayUtils.add(array: any, obj: any, {idKey : 'id', pIdKey : 'parentId', childKey : 'children'} = {});**

| 参数 | 名称 | 必传 | 参数类型
| ------ | ------ | ------ | ------ |
| array | 被操作的数组 | 是 | Array |
| obj | 被添加的元素 | 是 | any |
| keys | 主键、子属性对应关系 | 否 | string |

**示例1：添加元素**
```js
function add01() {
    let data = [{
        'id': 'A', 'type': '1', 'children': [
            {
                'id': 'A01', 'type': '2', 'children': [
                    {'id': 'A01-01', 'type': '3'}
                ]
            },
            {'id': 'A03', 'type': '3'}
        ]
    }];
    let child = {'id': 'A03-01', 'parentId': 'A03'};
    let result = ArrayUtils.add(data, child);
    console.log(result,JSON.stringify(data));
}
function add02() {
    let data = [{
        'orgId': 'A', 'type': '1', 'children': [
            {'orgId': 'A01', 'type': '2'},
            {'orgId': 'A03', 'type': '3'}
        ]
    }];
    let child = {'orgId': 'A03-01', 'parentId': 'A03'};
    let result = ArrayUtils.add(data, child,{idKey:'orgId'});
    console.log(result,JSON.stringify(data));
}
function add03() {
    let data = [{
        'orgId': 'A', 'type': '1', 'items': [
            {'orgId': 'A01', 'type': '2'},
            {'orgId': 'A03', 'type': '3'}
        ]
    }];
    let child = {'orgId': 'A03-01', 'parentId': 'A03'};
    let result = ArrayUtils.add(data, child,{idKey:'orgId',childKey:'items'});
    console.log(result,JSON.stringify(data));
}
function add04() {
    let data = [{
        'id': 'A', 'type': '1', 'children': [
            {'id': 'A03', 'type': '3'}
        ]
    }];
    let keys = {'id': 'key'};
    let child = {'id': 'A03-01', 'parent': {'id': 'A03'}};
    let result = ArrayUtils.add(data, child,{'pIdKey':'parent'});
    console.log(result,JSON.stringify(data));
}
```
### 移除元素
**ArrayUtils.remove(array,value,key);**

| 参数 | 名称 | 必传 | 参数类型
| ------ | ------ | ------ | ------ |
| array | 被操作的数组 | 是 | Array |
| value | 需要移除的值 | 是 | any |
| keys | 主键、子属性对应关系 | 否 | string |

**示例1：移除字符串**
```js
//字符串移除，第一个参数是被操作的数组，第二个参数是需要移除的字符串
function testArray(){
    let arr=['a','b','c'];
    ArrayUtils.remove(arr,'b');
    console.log(arr.join(','));//a,c
}
```
**示例2：对象移除**
```js
function removeRoot01() {
    let objArr=[{'id':'1','name':'赵云'},{'id':'2','name':'诸葛亮'}];
    ArrayUtils.remove(objArr,{'id':'2'});
    console.log(JSON.stringify(objArr));//[{'id':'1','name':'赵云'}]
}
```
**示例3：对象移除**
```js
function removeRoot02() {
    let objArr=[{'userId':'1','name':'赵云'},{'userId':'2','name':'诸葛亮'}];
    ArrayUtils.remove(objArr,{'userId':'2'},{idKey:'userId'});
    console.log(JSON.stringify(objArr));//[{'userId':'1','name':'赵云'}]
}
```
**示例4：子节点移除**
```js
function removeChild01() {
    let objArr=[{'id':'1','name':'山东省','children':[{'id':'2','name':'济南市'}]}];
    ArrayUtils.remove(objArr,{'id':'2'});
    console.log(JSON.stringify(objArr));//[{'id':'1','name':'赵云'}]
}
function removeChild02() {
    let objArr=[{'id':'1','name':'山东省','items':[{'id':'2','name':'济南市'}]}];
    ArrayUtils.remove(objArr,{'id':'2'},{childKey:'items'});
    console.log(JSON.stringify(objArr));//[{'id':'1','name':'赵云'}]
}
```
### 更新元素
**ArrayUtils.update(array,obj,keys);**

| 参数 | 名称 | 必传 | 参数类型
| ------ | ------ | ------ | ------ |
| array | 被操作的数组 | 是 | Array |
| obj | 需要更新的对象 | 是 | any |
| keys | 主键、子属性对应关系 | 否 | string |

**示例1：更新根节点中的元素**
```js
//字符串移除，第一个参数是被操作的数组，第二个参数是需要更新的对象

function updateRoot01() {
    let obj={'id':'001','name':'001'};
    let array=[{'id':'001','name':'111'}];
    let newArray=ArrayUtils.update(array,obj);
    console.log(JSON.stringify(array));
}
```

**示例2：更新根节点中的元素**
```js
import { ArrayUtils } from 'great-jsutils';

function updateRoot02() {
    let obj={'userId':'002','name':'222'};
    let array=[{'userId':'002','name':'111'}];
    let newArray=ArrayUtils.update(array,obj,{idKey:'userId'});
    console.log(JSON.stringify(array));
}
```
**示例3：更新子节点中的元素**
```js
import { ArrayUtils } from 'great-jsutils';
function updateChildren01() {
    let obj={'id':'001','name':'001'};
    let array=[{'id':'a','name':'111','children':[{'id':'001','name':'222'}]}];
    ArrayUtils.update(array,obj);
    console.log(JSON.stringify(array));
}
```
**示例4：更新子节点中的元素**
```js
import { ArrayUtils } from 'great-jsutils';
function updateChildren02() {
    let obj={'userId':'001','name':'001'};
    let array=[{'userId':'A','name':'A','items':[{'userId':'001','name':'222'}]}];
    ArrayUtils.update(array,obj,{idKey:'userId',childKey:'items'});
    console.log(JSON.stringify(array));
}
```

**示例5：更新时，增加key
```javascript

function updateChildren03() {
    let obj={'userId':'001','name':'001','checked':true};
    let array=[{'userId':'A','name':'A','items':[{'userId':'001','name':'222'}]}];
    ArrayUtils.update(array,obj,{idKey:'userId',childKey:'items'},function(oldData,newData){
        return {'checked':newData['checked']};
    });
    console.log(JSON.stringify(array));

}
```
### 合并元素
**ArrayUtils.merge(array,obj,keys);**

| 参数 | 名称 | 必传 | 参数类型
| ------ | ------ | ------ | ------ |
| array | 被操作的数组 | 是 | Array |
| obj | 需要更新的对象 | 是 | any |
| keys | 主键、子属性对应关系 | 否 | string |
> 与update类似，这个会增加第二个参数中的新属性

### 属性替换
**ArrayUtils.updateKey(array,keys,function);**

| 参数 | 名称 | 必传 | 参数类型
| ------ | ------ | ------ | ------ |
| array | 被操作的数组 | 是 | Array |
| keys | 原key与新key的对应关系 | 是 | json |
| function | 自定义需要添加的属性 | 否 | string |

**示例1：属性替换**
```js
import { ArrayUtils } from 'great-jsutils';
//数组中的对象key替换，例如源数据为[{'name':'张三'}]替换为[{'text':'张三'}]
function testArray(){
    let datas=[{'name':'张三','sex':'1'}];
    let keys={'name':'text'};
    let result=ArrayUtils.updateKey(datas,keys);
    console.log(result);//{name: '张三', sex: '1'}
}
```

**示例2：属性替换，并添加新属性**
```js
//数组中对象key替换，例如源数据为[{'name':'张三','age':80}]替换为[{'text':'张三','age':80,'ageGroup':'老年人'}];
//这里是根据某些值特征，增加新的属性
function testArray(){
    let datas=[{'name':'张三','sex':'1'}];
    let keys={'name':'text'};
    let result=ArrayUtils.updateKey(data,keys,function(){
        if(data['age']>75){
            return {'ageGroup':'老年人'};
        }
    });
    console.log(result);//[{'text':'张三','age':80,'ageGroup':'老年人'}];
}
```

### 获取树节点
**ArrayUtils.get(array,obj,keys);**

| 参数 | 名称 | 必传 | 参数类型
| ------ | ------ | ------ | ------ |
| array | 被操作的数组 | 是 | Array |
| obj | 需要更新的对象 | 是 | any |
| keys | 主键、子属性对应关系 | 否 | string |

**示例1：根据主键获取**
```js
//从树状数组中，根据id的值获取节点数据

function get01() {
    let data = [ {'id': 'A01', 'type': '2'},{'id': 'A03', 'type': '3'}];
    let item = ArrayUtils.get(data, 'A03');
    console.log(item);//{'id': 'A03', 'type': '3'}
}
function get02() {
    let data = [ {'userId': 'A01', 'type': '2'},{'userId': 'A03', 'type': '3'}];
    let item = ArrayUtils.get(data, 'A03',{idKey:'userId'});
    console.log(item);//{'id': 'A03', 'type': '3'}
}
function get03() {
    let data = [ {'userId': 'A01', 'type': '2'},{'userId': 'A03', 'type': '3'}];
    let item = ArrayUtils.get(data, {'id':'A03'});
    console.log(item);//{'id': 'A03', 'type': '3'}
}
function get() {
    let data = [{
        'id': 'A', 'type': '1', 'children': [
            {
                'id': 'A01', 'type': '2', 'children': [
                    {
                        'id': 'A01-01', 'type': '3', 'children': [
                            {'id': 'A01-01-01', 'type': '3-01', 'children': [
                                    {'id': 'A01-01-01', 'type': '3-02'}
                                ]}
                        ]
                    }, {
                        'id': 'A01-02', 'type': '3', 'children': [
                            {'id': 'A01-02-01', 'type': '3-01', 'children': [
                                    {'id': 'A01-02-01-01', 'type': '3-02', 'children': [
                                            {'id': 'A01-02-01-01-01', 'type': '3-02'}
                                        ]}
                                ]}
                        ]
                    }
                ]
            },
            {'id': 'A03', 'type': '3'}
        ]
    }];
    let item = ArrayUtils.get(data, 'A01-02-01-01-01');
    console.log(item);//{ id: 'A01-02-01-01-01', type: '3-02' }
}
```
**示例2：根据主键获取**
```js
//从树状数组中，根据id的值获取节点数据
function getTreeNodeById(){
    let arr=[{'id':'A','type':'1','children':[
                {'id':'A01','type':'2','children':[
                    {'id':'A01-01','type':'3','children':[
                        {'id':'A01-01-01','type':'3-01'}
                    ]},
                    {'id':'A01-02','type':'3','children':[
                        {'id':'A01-02-01','type':'3-02'}
                    ]}
                ]},
                {'id':'A03','type':'3'}
            ]}];
    let item=ArrayUtils.get(arr,'A01-02-01','id','children');
    console.log(item);//{ id: 'A01-02-01', type: '3-02' }
}
```
### 是否是个有效的数组对象
**ArrayUtils.valid(array);**
>是否是个有效的数组对象，有则返回第一个子元素，否则返回false

| 参数 | 名称 | 必传 | 参数类型
| ------ | ------ | ------ | ------ |
| array | 被操作的数组 | 是 | Array |

**示例1：是否是个有效的数组对象**
```js
//从树状数组中，根据id的值获取节点数据
function valid(){
    let arr=[{'id':'A','type':'1','children':[
                {'id':'A01','type':'2','children':[
                    {'id':'A01-01','type':'3','children':[
                        {'id':'A01-01-01','type':'3-01'}
                    ]},
                    {'id':'A01-02','type':'3','children':[
                        {'id':'A01-02-01','type':'3-02'}
                    ]}
                ]},
                {'id':'A03','type':'3'}
            ]}];
    let item=ArrayUtils.valid(arr);
    console.log(item);
}
```
### 节点向上移动操作

**示例一：将第二个元素上移到第2个位置**
```js
/**
* 将第二个元素上移2个位置
*/
function move01() {
   let arr=['a','b','c','d','e'];
    //ArrayUtils
    let index=2;
    let size=2;
    ArrayUtils.up(arr,index,{size});
    console.log(arr);
}
```

**示例二：将第二个元素上移到第2个位置**
```js
/**
* 将第二个元素下移到第2个位置
*/
function move01() {
   let arr=['a','b','c','d','e'];
    //ArrayUtils
    let index=2;
    let end=2;
    ArrayUtils.up(arr,index,{end});
    console.log(arr);
}
```
### 节点向下移动操作

**示例一：将第二个元素，移动到第1个位置**
```js
/**
* 将第二个元素下移2个位置
*/
function down10() {
    let arr=['a', 'b', 'c', 'd'];
    console.log('移动前',arr);
    let index=2;
    let end=1;
    ArrayUtils.down(arr,index,{end});
    console.log('移动后',arr);
    /**
     * 移动前 [ 'a', 'b', 'c', 'd' ]
     * 移动后 [ 'a', 'c', 'b', 'd' ]
     */
}
```
**示例一：将第二个元素下移到第2个位置**
```js
/**
* 将第二个元素下移2个位置
*/
function move01() {
   let arr=['a','b','c','d','e'];
    //ArrayUtils
    let index=2;
    let size=2;
    ArrayUtils.down(arr,index,{size});
    console.log(arr);
}
```

**示例二：将第二个元素下移到第2个位置**
```js
/**
* 将第二个元素下移到第2个位置
*/
function move01() {
   let arr=['a','b','c','d','e'];
    //ArrayUtils
    let index=2;
    let end=2;
    ArrayUtils.down(arr,index,{end});
    console.log(arr);
}
```

### 将指定索引的节点移到底部
**将第二个元素移动到底部**
```js
function moveBottom() {
    let arr = ['a', 'b', 'c', 'd', 'e'];
    //ArrayUtils
    let index = 2;
    ArrayUtils.bottom(arr,index);
    console.log(arr);
}
```

**移动对象**
```js
function moveBottom2() {
    let arr = [{name:'1'},{name:'2'},{name:'3'},{name:'4'}];
    let index = 2;
    ArrayUtils.bottom(arr,index);
    console.log(arr);
    /**
     * 打印结果：
     * [ { name: '1' }, { name: '2' }, { name: '4' }, { name: '3' } ]
     */
}
```

### 将指定索引的节点移到顶部
**将第二个元素移动到顶部**
```js
function top() {
    let arr = ['a', 'b', 'c', 'd', 'e'];
    //ArrayUtils
    let index = 2;
    ArrayUtils.top(arr,index);
    console.log(arr);
}
```

**移动对象**
```js
function top() {
    let arr = [{name:'1'},{name:'2'},{name:'3'},{name:'4'}];
    let index = 2;
    ArrayUtils.top(arr,index);
    console.log(arr);
    /**
     * 打印结果：
     * [ { name: '3' }, { name: '1' }, { name: '2' }, { name: '4' } ]
     */
}
```

### 节点位置交换
```
/**
 * 两个元素交换位子
 * @param arr：被移动的数组
 * @param index1：被移动的元素一
 * @param index2：被移动的元素二
 * @returns {any}
 */
ArrayUtils.swap(arr, index1, index2);
```
**示例：将第一个和第三个进行交换**
```js
function swap(){
    let arr = [{name:'1'},{name:'2'},{name:'3'},{name:'4'}];
    ArrayUtils.swap(arr,1,3);
    console.log(arr);
    /**
     * 打印结果：
     * [ { name: '1' }, { name: '4' }, { name: '3' }, { name: '2' } ]
     */
}
```
##二、 加密
**示例1：md5**
```js
//字符串的加密
import {JsUtilsApi } from 'great-jsutils';
function md5() {
  JsUtilsApi.md5('admin123456')
}
```
**示例2：Base64**
```js
//字符串的加密、解密
import {Base64 } from 'great-jsutils';
function base64() {
console.log('base64：',Base64.encode('123'));
console.log('base64：',Base64.decode('MTIz'));
}
```
**示例3：md5File**，读取文件内容生成md5值
```js
//字符串的加密、解密
import {JsUtilsApi } from 'great-jsutils';
function md5File() {
    JsUtilsApi.md5File(file).then(
      (md5)=>{ // 成功回调
        this.file.fileMd5 = md5;
      }
    );
}
```

##三、 时间工具类
* 常量
```js
FORMAT_FULL = 'yyyy-MM-dd hh:mm:ss';
FORMAT_FULL_IE = 'yyyy/MM/dd hh:mm:ss';
FORMAT_FULL_CN = 'yyyy年MM月dd日 hh时mm分ss秒';
FORMAT_YMD = 'yyyy-MM-dd';
FORMAT_YMD_IE = 'yyyy/MM/dd';
FORMAT_YMD_CN = 'yyyy年MM月dd日';
FORMAT_HMS = 'hh:mm:ss';
FORMAT_HMS_CN = 'hh时mm分ss秒';
```
```js
import { TimeUtils } from 'great-jsutils';
```
**判断是否是日期类型**
```js
TimeUtils.isDate(args);
```
**获取某天开始、结束时间**
**TimeUtils.getDayTime(n:number);**

| 参数 | 名称 | 必传 | 参数类型
| ------ | ------ | ------ | ------ |
| n | 获取n天前时间，不传则为当天时间 | 否 | number |

>根据传入的数字，获取n天前的开始结束时间，正数则往后推，负数则往前推
```js
import {TimeUtils } from 'great-jsutils';
function testTime(){
    console.log('当天开始、结束时间',TimeUtils.getDayTime());
    //当天开始、结束时间 { start: '2018-08-31 00:00:00', end: '2018-08-31 24:59:59' }
    console.log('获取昨天时间：',TimeUtils.getDayTime(-1));
    console.log('获取前天时间：',TimeUtils.getDayTime(-2));
    console.log('获取明天时间：',TimeUtils.getDayTime(1));
    console.log('获取后天时间：',TimeUtils.getDayTime(1));
}
```
**获取某周开始、结束时间**
```js 
TimeUtils.getWeekTime(n:number); 
```
根据传入的数字，获取n周前的开始结束时间，正数则往后推，负数则往前推
```js
import {TimeUtils } from 'great-jsutils';
function testTime(){
    console.log('本周开始、结束时间',TimeUtils.getWeekTime());
    //本周开始、结束时间 { start: '2018-09-17 00:00:00', end: '2018-09-23 24:59:59' }
    console.log('上周开始、结束时间',TimeUtils.getWeekTime(-1));
    //上周开始、结束时间 { start: '2018-09-10 00:00:00', end: '2018-09-16 24:59:59' }
}
```
**获取某月开始、结束时间**
```js
 TimeUtils.getMonthTime(integer);
 ```
根据传入的数字，获取n月前的开始结束时间，正数则往后推，负数则往前推
```js
import {TimeUtils } from 'great-jsutils';
function testTime(){
    console.log('本月开始、结束时间',TimeUtils.getMonthTime());
    //本月开始、结束时间 { start: '2018-09-01 00:00:00', end: '2018-09-30 24:59:59' }
    console.log('上月开始、结束时间',TimeUtils.getMonthTime(-1));
    //上月开始、结束时间 { start: '2018-08-01 00:00:00', end: '2018-08-31 24:59:59' }
}
```
**获取某季度开始、结束时间**
```js 
TimeUtils.getQuarterTime(n:number); 
```
根据传入的数字，获取n月前的开始结束时间，正数则往后推，负数则往前推
```js
import {TimeUtils } from 'great-jsutils';
function testTime(){
    console.log('本季度开始结束时间',TimeUtils.getQuarterTime());
    //本季度开始结束时间 { start: '2018-07-01 00:00:00', end: '2018-09-30 24:59:59' }
    console.log('上季度开始结束时间',TimeUtils.getQuarterTime(-1));
}
```
**获取某年开始、结束时间**
```js 
TimeUtils.getYearTime(n:number); 
```
根据传入的数字，获取n年前的开始结束时间，正数则往后推，负数则往前推
```js
import {TimeUtils } from 'great-jsutils';
function testTime(){
    console.log('本年开始结束时间',TimeUtils.getYearTime());
    //本年开始结束时间 { start: '2018-01-01 00:00:00', end: '2018-12-31 24:59:59' }
    console.log('上年开始结束时间',TimeUtils.getYearTime(-1));
}
```
**获取N天内的开始、结束时间**
>getWinthInDayTime

| 参数 | 名称 | 必传 | 参数类型
| ------ | ------ | ------ | ------ |
| num | 指定天数 | 否 | number |
```
function getWinthInDayTime(){
    let num1 = -29;// 向前推获取30天内的时间
    let time1 = TimeUtils.getWinthInDayTime(num1);
    console.log(`\n${num1}天内的开始、结束时间：\n`, time1);
    /*
     -29天内的开始、结束时间：
     { start: '2019-03-23 00:00:00', end: '2019-04-21 24:59:59' }
     */

    let num2 = 29; // 向后推，获取30天内的时间
    let time2 = TimeUtils.getWinthInDayTime(num2);
    console.log(`\n${num2}天内的开始、结束时间：\n`, time2);
    /*
     29天内的开始、结束时间：
     { start: '2019-04-21 00:00:00', end: '2019-05-20 24:59:59' }
     */
}
```

**格式化时间**
**TimeUtils.format(date:Date,format:string)**

| 参数 | 名称 | 必传 | 参数类型
| ------ | ------ | ------ | ------ |
| date | 需要格式化的时间 | 否 | Date |
| format | 需要转换的格式 | 否 | string |
```js
import {TimeUtils } from 'great-jsutils';
function testTime(){
    console.log('格式化时间（默认的格式化类型）：',TimeUtils.format());//当前时间
    //格式化时间（默认的格式化类型）： 2018-09-23 17:18:19
    console.log('格式化时间（默认的格式化类型）：',TimeUtils.format(new Date()));
    //格式化时间（默认的格式化类型）： 2018-09-23 17:18:19
    console.log('格式化时间（根据传入的参数格式）：',TimeUtils.format(new Date(),'yyyy-MM-dd hh时'));
    //格式化时间（根据传入的参数格式）： 2018-09-23 17时
    console.log('格式化时间（API提供的类型）：',TimeUtils.format(new Date(),TimeUtils.FORMAT_YMD));
    //格式化时间（API提供的类型）： 2018-09-23
}
```
**生成一个随机时间**
```javascript
/* 获取一个随机时间 */
function random() {
    let date =  TimeUtils.random();
    let dateStr = TimeUtils.format(date);
    console.log(dateStr);
}
random();
```
**根据当前时间，输出早上好、上午好……**
```javascript
function sayHello() {
    let hello =  TimeUtils.sayHello();
    console.log(hello);
}
sayHello();
```
**字符串转时间**
```js
function parse(){
    let date = TimeUtils.parse('2019年11年9日 11点11分11秒');
    if(date){
        console.log('parse：',TimeUtils.format(date));
        //parse： 2019-11-09 11:11:11
    }else{
        console.log('null');
    }
}
```
**获取某月最后一天的时间**
```js
TimeUtils.getMonthEndDateByDateStr(dateStr);
```
##四、 字符串
```js
import { StringUtils } from 'great-jsutils';
```
**示例1：删除全部空格**
```js
import {StringUtils } from 'great-jsutils';
StringUtils.trim(str);
```
**示例2：删除前后空格**
```js
import {StringUtils } from 'great-jsutils';
StringUtils.trimAround(str);
```

##五、 json
```js
import { JsonUtils } from 'great-jsutils';
```
**示例1：判断是否为json**
```js
import {JsonUtils } from 'great-jsutils';
function json(){
    let str1='123';
    console.log(str1,JsonUtils.isJsonString(str1));
    let str2="{'name':'1'}";
    console.log(str2,JsonUtils.isJsonString(str2));
    let str3="{name:'1'}";
    console.log(str3,JsonUtils.isJsonString(str3));
    let str4="{'name':'xt'}";
    console.log(str4,JsonUtils.isJsonString(str4));
}
```
**示例2：字符串转json**
```js
import {JsonUtils } from 'great-jsutils';
let str4="{'name':'xt'}";
JsonUtils.toJson(str4);
```
**示例3：syntaxHighlight**
```js
import {JsonUtils } from 'great-jsutils';
let str4="{'name':'xt'}";
JsonUtils.syntaxHighlight(str4);
```
```js
/**
 * 是否是jsonStr
 */
JsonUtils.isJsonString
```
```js
/**
 * 转成jsonStr
 */
JsonUtils.toJsonStr
```
```js
/**
 * 转成json对象
 */
JsonUtils.toJson
```
```js
/**
 * json转前端实体类
 */
JsonUtils.toClassModel(json,{notes:false})
```
##六、 正则RegexpUtils

```js
import {RegexpUtils} from 'great-jsutils';
```
### 1、数字验证
```js
/**
 * 数字验证
 * 验证数字是否是规定的范围格式
 * 例如：是否为指定的小数位数、是否大于某个数字、是否小于某个数字、是否在某个数据范围之间
 */
RegexpUtils.isNumber(str,{
    max:'最大值',
    min:'最小值',
    maxScale:'最大小数位数',
    minScale:'至少小数位数',
    scale:'小数位数'
});
```
**场景示例**
```js
let numStr = "123.222";

// 场景一：检查输入的是否为数字
let result1 = RegexpUtils.isNumber(numStr);
console.log(numStr+'是否为数字：', result1);
//打印结果： 123.222是否为数字：true

// 场景二：检查输入的小数是否为三位
let result2 = RegexpUtils.isNumber(numStr,{scale:3});
console.log(numStr+'小数位数：==3',result2);
//打印结果： 123.222小数位数：==3 true

// 场景三：检查小数位数是否多于三位
let result3 = RegexpUtils.isNumber(numStr,{minScale:3});
console.log(numStr+'小数位数：>=3',result3);
//打印结果： 123.222小数位数：>=3 true

// 场景四：检查小数位数的个数是否多于4个、少于5个
let result4 = RegexpUtils.isNumber(numStr,{minScale:4, maxScale:5});
console.log(numStr+'小数位数：4-5',result4);
//打印结果： 123.222小数位数：4-5 false

// 场景五：检查小数位数是否多于5个
let result5 = RegexpUtils.isNumber(numStr,{maxScale:5});
console.log(numStr+'小数位数：<5',result5);
//打印结果： 123.222小数位数：<5 true

// 场景六：检查数字是否大于5
let result6 = RegexpUtils.isNumber(numStr,{min:5});
console.log(numStr+'>5：',result6);
//打印结果： 123.222>5： true

// 场景七：检查数字是否大于5，并且小于200
let result7 = RegexpUtils.isNumber(numStr,{min:5, max:200});
console.log(numStr+'>5 && '+numStr+'<200：',result7);
//打印结果：123.222>5 && 123.222<200： true

// 场景八：检查数字是否小于555
let result8 = RegexpUtils.isNumber(numStr,{max:555});
console.log(numStr+'<555：',result8);
//打印结果： 123.222<555： true

let result9 = RegexpUtils.isNumber(numStr,{});
console.log(numStr+'｛｝：',result9);
//打印结果： 123.222｛｝： true
```
### 2、字节个数验证
```js
/**
 * 字节个数验证
 * 由于数据库中定义的字段长度为字节长度，
 * 所以中英文混合输入时，为了避免避免输入超长，
 * 需要检查输入数字的字节长度
 */
RegexpUtils.byteLength(str,{
    maxLength:'最大长度',
    minLength:'最小长度',
});
```
**场景示例**
```js
let str = '富强prosperity/1/2/3';

let result = RegexpUtils.byteLength(str,{maxLength: 10});
console.log(`${str}字节数<10：`,result);
// 打印结果：富强prosperity/1/2/3字节数<10： false

let result2 = RegexpUtils.byteLength(str,{minLength: 10});
console.log(`${str}字节数>10：`,result2);
// 打印结果：富强prosperity/1/2/3字节数>10： true

let result3 = RegexpUtils.byteLength(str,{minLength: 10, maxLength: 12});
console.log(`${str}字节数>10&&<12：`,result3);
// 打印结果：富强prosperity/1/2/3字节数>10&&<12： false

let result4 = RegexpUtils.byteLength(str,{minLength: 10, maxLength: 20});
console.log(`${str}字节数>10&&<20：`,result4);
// 打印结果：富强prosperity/1/2/3字节数>10&&<20： true
```

### 3、匹配中文信息
```js
let str = '富强prosperity 、民主democracy/1/2/3';
console.log(RegexpUtils.matchChinese(str));
// 打印结果：[ '富', '强', '、', '民', '主' ]
```

### 4、其他操作
```js
let str = 'zhaoqingkaitt@163.com';

// 是否为邮箱
console.log('邮箱：', RegexpUtils.isEmail(str));
// 打印结果：邮箱： true

// 是否为中文
console.log('中文：', RegexpUtils.isChinese(str));
// 打印结果： 中文： false

// 是否为身份证号
console.log('身份证号：', RegexpUtils.isIdentityCard(str));
// 打印结果： 身份证号： false

// 是否为MAC地址
console.log('MAC地址：', RegexpUtils.isMac(str));
// 打印结果： MAC地址： false

// 是否为http地址
console.log('HTTP地址：', RegexpUtils.isUrl(str));
// 打印结果： HTTP地址： false

// 是否为整数
console.log('整数：', RegexpUtils.isInteger(str));
// 打印结果： 整数： false

// 纳税人识别号格式
console.log('整数：', RegexpUtils.isTaxpayerIdentificationNumber(str));
// 打印结果： 整数： false
```
###5、去除空格
```js
// 去除空格
RegexpUtils.trim(str);
// 去除前后空格
RegexpUtils.trimAround(str);
// 去除前空格
RegexpUtils.trimLeft(str);
// 去除后空格
RegexpUtils.trimRight(str);
```
###6、单词转变量
```js
let str= 'hello word';
//首字母大写
RegexpUtils.upperCaseFirst(str);
// 打印 HelloWord

// 首字母转小写
RegexpUtils.lowerCaseFirst(str);

// 小驼峰
RegexpUtils.lowerCamelCase(str);
// 打印 helloWord
```
###7、身份证呈
```js
// 是否为身份证号
RegexpUtils.isIdentityCard(idCard);
// 获取出生日期
RegexpUtils.getBirthdayStrByIdCard(idCard);
// 获取年龄
RegexpUtils.getAgeByIdCard(idCard);
// 获取性别
RegexpUtils.getSexByIdCard(idCard);
// 获取性别、年龄、出生日期
RegexpUtils.getPersonInfoByIdCard(idCard);
```

##七、 对象操作

```js
import {ObjectUtils} from 'great-jsutils';

```


```js
/**
 * 清除对象中的空值
 */
function obj01(){
    let obj={a:null,b:'',c:2,d:'aa'};
    ObjectUtils.filter(obj);
    console.log('obj\t',obj); //obj   { c: 2, d: 'aa' }
}
```

```js
/**
 * 清除对象中的空值。
 * 并指定其他需要强制移除的key
 */
function obj02(){
    let obj={a:null,b:'',c:2,d:'aa'};
    let removeKeys=['d'];
    ObjectUtils.filter(obj,{removeKeys});
    console.log('obj\t',obj);//obj   { c: 2}
}

```


```js
/**
 * 根据指定函数确定需要移除的key
 * 下面示例将删除值长度为2 或 值为b的key
 */
function obj03(){
    let obj={a:'dd',b:'b',c:'ddd',d:'aa'};
    function fun(v){
        return v=='b' || v.length==2;
    }
    ObjectUtils.filter(obj,{fun});
    console.log('obj\t',obj);// { c: 'ddd' }
}

```

##八、 number
### 1.1随机生成一组整数
>默认返回一个小于10的整数，可以指定返回的最大值、最小值，以及返回的个数
```js
import { NumberUtils } from 'great-jsutils';
```
**示例1：随机生成一个小于10的整数**
```js
NumberUtils.randomInt();
```
**示例2：随机生成一个小于100的整数**
```js
NumberUtils.randomInt({max:100});
```
**示例3：随机生成四个大于等于10，小于100的整数**
```js
NumberUtils.randomInt({max:100,min:10,number:4})
```

### 1.2随机生成一组浮点数
>默认返回一个小于10的浮点数，可以指定返回的最大值、最小值、小数位数，以及返回的个数

**示例1：随机生成一个小于10的两位小数的浮点数**
```js
NumberUtils.randomInt();
```
**示例2：随机生成一个小于100的两位小数的浮点数**
```js
NumberUtils.randomInt({max:100});
```
**示例3：随机生成四个大于等于10，小于100的两位小数的浮点数**
```js
NumberUtils.randomInt({max:100,min:10,number:4})
```
**示例4：随机生成四个大于等于10，小于100的三位小数的浮点数**
```js
NumberUtils.randomInt({max:100,min:10,number:4,scale3})
```
### 1.3 将数字转人民币大写
```js
console.log(NumberUtils.changeToChinese(1200));
```
### 1.4 将阿拉伯数字转中文表示方式
```js
console.log(NumberUtils.numberToChinese(12));
```
### 1.5 数字相加
```js
console.log(NumberUtils.sum(1.1,1.3));// 2.4
console.log(1.1+1.3);//2.4000000000000004
```
### 1.6 数字相减
```js
console.log(NumberUtils.sub(1.1,1.2));
```
### 1.7 数字相乘
```js
console.log(NumberUtils.mul(1.1,1.2));
```
### 1.8 数字相除
```js
console.log(NumberUtils.div(1.1,1.2));
```

##九、 DataTypeUtils
```js
import {DataTypeUtils} from 'great-jsutils';
```

```js
/**
 * 获取对象类型
 */
DataTypeUtils.getDataType(o);
```
```js
/**
 * 是否为空对象
 */
DataTypeUtils.isNull(o);
```
```js
/**
 * 是否为undefined
 */
DataTypeUtils.isUndefined(o);
```
```js
/**
 * 是否为对象
 */
DataTypeUtils.isObject(o);
```
```js
/**
 * 是否为数组
 */
DataTypeUtils.isArray(o);
```
```js
/**
 * 是否为字符串
 */
DataTypeUtils.isString(o);
```
```js
/**
 * 是否为数字
 */
DataTypeUtils.isNumber(o);
```
```js
/**
 * 是否为布尔
 */
DataTypeUtils.isBoolean(o);
```
```js
/**
 * 是否为函数
 */
DataTypeUtils.isFunction(o);
```
```js
/**
 * 是否为日期
 */
DataTypeUtils.isDate(o);
```
```js
/**
 * 是否为正则
 */
DataTypeUtils.isRegExp(o);
```
```js
/**
 * 是否为错误对象
 */
DataTypeUtils.isError(o);
```
```js
/**
 * 是否为Symbol对象
 */
DataTypeUtils.isSymbol(o);
```
```js
/**
 * 是否为promise对象
 */
DataTypeUtils.isPromise(o);
```
```js
/**
 * 是否为set对象
 */
DataTypeUtils.isSet(o);
```

##十、 数据生成器：DataGeneratorUtils
```js
import {DataGeneratorUtils} from 'great-jsutils';
```
### 1. 生成姓名
**1.1、 生成一个姓名**
```js
let personName = DataGeneratorUtils.personName();
```
**1.2、 生成多个姓名**
```js
let personNames = DataGeneratorUtils.personName({size:8});
```
### 2. 生成一个手机号
**2.1、 生成一个手机号**
```js
let mobile = DataGeneratorUtils.mobile();
```
**2.2、 生成多个手机号**
```js
let mobiles = DataGeneratorUtils.mobile({size:8});
```
### 3. 生成字母
**3.1、 生成一个字母，默认为一个且为大写**
```js
let letter = DataGeneratorUtils.letter();
console.log(letter);//B
```
**3.2、 生成多个字母，通过length指定长度为2**
```js
let letters = DataGeneratorUtils.letter({length:2});
console.log(letters);//BD
```
**3.3、 生成多组字母**
```js
let letters = DataGeneratorUtils.letter({size:2});
console.log(letters);//['D', 'W']
```
**3.4、 生成多组字母，且长度为4**
```js
let letters = DataGeneratorUtils.letter({size:2, length:4});
console.log(letters);//['DACK', 'BKJA']
```
**3.5、 生成小写字母**
```js
let letters = DataGeneratorUtils.letter({length:4, upperCase:false});
console.log(letters);//aabc
```
### 4. 从数组中随机获取一个元素
```js
let personName = DataGeneratorUtils.getElementByArray(array);
```
### 5. 其他
**5.1、随机生成整数、小数**
>可以指定最大数、最小数、生成的个数等
```js
import {NumberUtils} from 'great-jsutils';
```
**5.2、随机生成时间**
>可以格式化时间、获取一个月内、上下个月、上下个周内等
```js
import {TimeUtils} from 'great-jsutils';
```
##十一、 CommonUtils
### 1.1、 CommonUtils.isIos();
是否为ios系统
### 1.2、CommonUtils.isPC();
是否为pc端
### 1.3、 CommonUtils.browserType();
浏览器类型
### 1.4、CommonUtils.getRandomColor();
随机生成一个16进制颜色值
### 1.5、CommonUtils.uuid();
生成一个uuid
## 十二、ValueUtils
```js
import {ValueUtils} from 'great-jsutils';
```
### 1.1、空值校验(isNullValue)
```js
let a = [],a1={},a2=null,a3,a4=' ';
console.log('ValueUtils.isNullValue(',a,'):', ValueUtils.isNullValue(a));// 打印：true
console.log('ValueUtils.isNullValue(',a1,'):', ValueUtils.isNullValue(a1));// 打印：true
console.log('ValueUtils.isNullValue(',a2,'):', ValueUtils.isNullValue(a2));// 打印：true
console.log('ValueUtils.isNullValue(',a3,'):', ValueUtils.isNullValue(a3));// 打印：true
console.log('ValueUtils.isNullValue(',a4,'):', ValueUtils.isNullValue(a4));// 打印：false
console.log('ValueUtils.isNullValue(',a4,',true):', ValueUtils.isNullValue(a4, true));// 打印：true
```
### 1.2、是否为数字(isNumberValue)
```js
let b="123", b1="a23", b2=23;
console.log('ValueUtils.isNumberValue(',b,'):', ValueUtils.isNumberValue(b)); // 打印：true
console.log('ValueUtils.isNumberValue(',b1,'):', ValueUtils.isNumberValue(b1));// 打印：false
console.log('ValueUtils.isNumberValue(',b2,'):', ValueUtils.isNumberValue(b2));// 打印：true
```
### 1.3、是否为空数组(isEmptyArray)
```js
let c = [], c1, c2={}, c3=[1], c4=[{name:'张三'}];
console.log('ValueUtils.isEmptyArray(',c,'):', ValueUtils.isEmptyArray(c));// 打印：true
console.log('ValueUtils.isEmptyArray(',c1,'):', ValueUtils.isEmptyArray(c1));// 打印：false
console.log('ValueUtils.isEmptyArray(',c2,'):', ValueUtils.isEmptyArray(c2));// 打印：false
console.log('ValueUtils.isEmptyArray(',c3,'):', ValueUtils.isEmptyArray(c3));// 打印：false
console.log('ValueUtils.isEmptyArray(',c4,'):', ValueUtils.isEmptyArray(c4));// 打印：false
```
### 1.4、是否为非空数组(isNotEmptyArray)

## 十三 BrowserUtils
```js
// 获取浏览器版本信息
BrowserUtils.getBrowser();
```
## 日志LogUtils

## SessionStroage

## bug修复
**2019.0817**

| key | value |
| ------ | ------ |
| 版本 | 1.2.0 |
| 升级说明 | 数组移除方法，子节点移除时优化 |

**2019.0829**

| key | value |
| ------ | ------ |
| 版本 | 1.2.1 |
| 升级说明 | 根据json转model类 |
```
JsonUtils.toClassModel(jsonStr);
```
**2019.0905**

| key | value |
| ------ | ------ |
| 版本 | 1.2.2 |
| 升级说明 | 增加BankCardUtils、AjaxUtils |
```
JsonUtils.toClassModel(jsonStr);
```
**2019.0929**

| key | value |
| ------ | ------ |
| 版本 | 1.2.4 |
| 升级说明 | 小数正则 |
```
RegexpUtils.isDecimal(num);
```
**2019.1001**

| key | value |
| ------ | ------ |
| 版本 | 1.2.5 |
| 升级说明 | 代码格式化 |
```
HighlightUtils.syntaxHighlight(num);
HighlightUtils.formatFunction(fn,fnName);
HighlightUtils.formatText(num);
HighlightUtils.formatHtml(num);
HighlightUtils.escapeHtml(num);
```
**2019.1004**
```
//深拷贝
ObjectUtils.deepClone
```
**2019.1008**
```
//深拷贝
ObjectUtils.clone
//数据类型
DataTypeUtils.is……
```

**2019.1013**  

| key | value |
| ------ | ------ |
| 版本 | 1.2.6 |
| 升级说明 | json转实体 |
```
toClassModel(json,{notes:false})
```

**2019.1026**  

| key | value |
| ------ | ------ |
| 版本 | 1.3.1 |
| 升级说明 | 生成数字优化 |
```
toClassModel(json,{notes:false})
```

**2020.0801**  

| key | value |
| ------ | ------ |
| 版本 | 1.3.6 |
| 升级说明 | 空值判断 |

___感谢你的支持，我将持续优化我的服务，希望为你提供更大的帮助！___   
![感谢你的支持](http://zhtt.gitee.io/cdn/image/pay.png)    
___感谢你的支持，我将持续优化我的免费的服务，希望为你提供更大的帮助！___    
![感谢你的支持](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAucAAAHKCAYAAACg3eW9AAAgAElEQVR4nOyd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%0ADIKICwgICAgIjA3+HyBZc7MY5RyeAAAAAElFTkSuQmCC)
